(include "test-colseq.scm")
(include "test-hook.scm")
(include "test-parameter.scm")
(include "test-process.scm")
(include "test-record.scm")
(include "test-generator.scm")
(include "test-bitvector.scm")
(include "test-atomic.scm")
(include "test-lazy.scm")
(include "test-unicode.scm")
